==> leechcraft-0.3.80_rc20101109.tar.bz2: leechcraft-0.3.75_rc20101109/src/plugins/summary/leechcraft_summary_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ar_SA">
<context>
    <name>LeechCraft::Plugins::Summary::Core</name>
    <message>
        <location filename="core.cpp" line="116"/>
        <location filename="core.cpp" line="319"/>
        <source>Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="183"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="184"/>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="185"/>
        <source>State</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Summary::OperationalModel</name>
    <message>
        <location filename="operationalmodel.cpp" line="30"/>
        <source>Entity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="operationalmodel.cpp" line="31"/>
        <source>Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="operationalmodel.cpp" line="32"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Summary::RequestNormalizer</name>
    <message>
        <location filename="requestnormalizer.cpp" line="51"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="requestnormalizer.cpp" line="52"/>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="requestnormalizer.cpp" line="53"/>
        <source>State</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="requestnormalizer.cpp" line="69"/>
        <source>Request validation error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="requestnormalizer.cpp" line="85"/>
        <source>Request parsing error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="requestnormalizer.cpp" line="109"/>
        <source>Open/close braces mismatch: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Summary::Summary</name>
    <message>
        <location filename="summary.cpp" line="87"/>
        <source>Summary of downloads and recent events</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Summary::SummaryWidget</name>
    <message>
        <location filename="summarywidget.cpp" line="49"/>
        <source>Ctrl+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="summarywidget.cpp" line="471"/>
        <source>S: %1 [%2]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="summarywidget.cpp" line="475"/>
        <source>Summary [%1]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <location filename="searchwidget.ui" line="14"/>
        <source>Search parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchwidget.ui" line="33"/>
        <source>String</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchwidget.ui" line="38"/>
        <source>Wildcard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchwidget.ui" line="43"/>
        <source>Regexp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchwidget.ui" line="48"/>
        <source>Tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchwidget.ui" line="65"/>
        <source>AND</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchwidget.ui" line="72"/>
        <source>OR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> leechcraft-0.4.75_rc20110524.tar.bz2: leechcraft-0.4.75_rc20110524/src/plugins/summary/leechcraft_summary_ar.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ar_SA">
<context>
    <name>LeechCraft::Plugins::Summary::Core</name>
    <message>
        <location filename="core.cpp" line="122"/>
        <location filename="core.cpp" line="345"/>
        <source>Summary</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="189"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="190"/>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="core.cpp" line="191"/>
        <source>State</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Summary::OperationalModel</name>
    <message>
        <location filename="operationalmodel.cpp" line="30"/>
        <source>Entity</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="operationalmodel.cpp" line="31"/>
        <source>Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="operationalmodel.cpp" line="32"/>
        <source>Information</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Summary::RequestNormalizer</name>
    <message>
        <location filename="requestnormalizer.cpp" line="51"/>
        <source>Name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="requestnormalizer.cpp" line="52"/>
        <source>Status</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="requestnormalizer.cpp" line="53"/>
        <source>State</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="requestnormalizer.cpp" line="69"/>
        <source>Request validation error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="requestnormalizer.cpp" line="85"/>
        <source>Request parsing error: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="requestnormalizer.cpp" line="109"/>
        <source>Open/close braces mismatch: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Summary::SearchWidget</name>
    <message>
        <location filename="searchwidget.cpp" line="35"/>
        <source>Search categories</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Summary::Summary</name>
    <message>
        <location filename="summary.cpp" line="92"/>
        <source>Summary of downloads and recent events</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>LeechCraft::Plugins::Summary::SummaryWidget</name>
    <message>
        <location filename="summarywidget.cpp" line="50"/>
        <source>Ctrl+F</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="summarywidget.cpp" line="510"/>
        <source>S: %1 [%2]</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="summarywidget.cpp" line="514"/>
        <source>Summary [%1]</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <location filename="searchwidget.ui" line="14"/>
        <source>Search parameters</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchwidget.ui" line="73"/>
        <source>String</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchwidget.ui" line="78"/>
        <source>Wildcard</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchwidget.ui" line="83"/>
        <source>Regexp</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchwidget.ui" line="88"/>
        <source>Tags</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchwidget.ui" line="39"/>
        <source>AND</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="searchwidget.ui" line="49"/>
        <source>OR</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
